===========
 mine-init
===========
----------------------------------------------------------
 A docker friendly startup routine for Minecraft servers.
----------------------------------------------------------

|build-status| |coverage|

Main Documentation
==================

`Main Index`_

.. |build-status| image:: https://gitlab.routh.io/minecraft/tools/mine-init/badges/master/pipeline.svg
    :target: https://gitlab.routh.io/minecraft/tools/mine-init/pipelines

.. |coverage| image:: https://gitlab.routh.io/minecraft/tools/mine-init/badges/master/coverage.svg
    :target: http://minecraft.pages.routh.io/tools/mine-init/reports/
    :alt: Coverage status

.. _Main Index: http://minecraft.pages.routh.io/tools/mine-init/
